pub struct EncoderOption {
pub bases: Vec<u8>,
}Expand description
Options for configuring the FASTA sequence encoder.
This struct provides configuration options for encoding FASTA sequences, such as which bases to consider during encoding.
Fields
bases- A vector of valid bases (as bytes) to use for encoding. Defaults to “ATCGN”.
Example
use deepbiop_fa::encode::option::EncoderOption;
let options = EncoderOption::default();Fields
bases: Vec<u8>Trait Implementations
Sourceimpl Clone for EncoderOption
impl Clone for EncoderOption
Sourcefn clone(&self) -> EncoderOption
fn clone(&self) -> EncoderOption
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EncoderOption
impl Debug for EncoderOption
Sourceimpl Default for EncoderOption
impl Default for EncoderOption
Sourcefn default() -> EncoderOption
fn default() -> EncoderOption
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EncoderOption
impl<'de> Deserialize<'de> for EncoderOption
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for EncoderOption
impl Display for EncoderOption
Sourceimpl<'py> IntoPyObject<'py> for EncoderOption
impl<'py> IntoPyObject<'py> for EncoderOption
Sourcetype Target = EncoderOption
type Target = EncoderOption
The Python output type
Sourcetype Output = Bound<'py, <EncoderOption as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <EncoderOption as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for EncoderOption
impl PyClass for EncoderOption
Sourceimpl PyClassImpl for EncoderOption
impl PyClassImpl for EncoderOption
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Options for configuring the FASTA sequence encoder.
///
/// This struct provides configuration options for encoding FASTA sequences,
/// such as which bases to consider during encoding.
///
/// # Fields
///
/// * `bases` - A vector of valid bases (as bytes) to use for encoding. Defaults to "ATCGN".
///
/// # Example
///
/// ```
/// use deepbiop_fa::encode::option::EncoderOption;
///
/// let options = EncoderOption::default();
/// ```
const RAW_DOC: &'static CStr = /// Options for configuring the FASTA sequence encoder. /// /// This struct provides configuration options for encoding FASTA sequences, /// such as which bases to consider during encoding. /// /// # Fields /// /// * `bases` - A vector of valid bases (as bytes) to use for encoding. Defaults to "ATCGN". /// /// # Example /// /// ``` /// use deepbiop_fa::encode::option::EncoderOption; /// /// let options = EncoderOption::default(); /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<EncoderOption>
type ThreadChecker = SendablePyClass<EncoderOption>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for EncoderOption
impl PyClassNewTextSignature for EncoderOption
const TEXT_SIGNATURE: &'static str = "(bases)"
Sourceimpl PyMethods<EncoderOption> for PyClassImplCollector<EncoderOption>
impl PyMethods<EncoderOption> for PyClassImplCollector<EncoderOption>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyStubType for EncoderOption
impl PyStubType for EncoderOption
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for EncoderOption
impl PyTypeInfo for EncoderOption
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for EncoderOption
impl Serialize for EncoderOption
impl DerefToPyAny for EncoderOption
impl ExtractPyClassWithClone for EncoderOption