pub struct FaEncoderOption {
pub bases: Vec<u8>,
}Fields
bases: Vec<u8>Trait Implementations
Sourceimpl Clone for FaEncoderOption
impl Clone for FaEncoderOption
Sourcefn clone(&self) -> FaEncoderOption
fn clone(&self) -> FaEncoderOption
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FaEncoderOption
impl Debug for FaEncoderOption
Sourceimpl Default for FaEncoderOption
impl Default for FaEncoderOption
Sourcefn default() -> FaEncoderOption
fn default() -> FaEncoderOption
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FaEncoderOption
impl<'de> Deserialize<'de> for FaEncoderOption
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FaEncoderOption
impl Display for FaEncoderOption
Sourceimpl<'py> IntoPyObject<'py> for FaEncoderOption
impl<'py> IntoPyObject<'py> for FaEncoderOption
Sourcetype Target = FaEncoderOption
type Target = FaEncoderOption
The Python output type
Sourcetype Output = Bound<'py, <FaEncoderOption as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <FaEncoderOption as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for FaEncoderOption
impl PyClass for FaEncoderOption
Sourceimpl PyClassImpl for FaEncoderOption
impl PyClassImpl for FaEncoderOption
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourcetype ThreadChecker = SendablePyClass<FaEncoderOption>
type ThreadChecker = SendablePyClass<FaEncoderOption>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature<FaEncoderOption> for PyClassImplCollector<FaEncoderOption>
impl PyClassNewTextSignature<FaEncoderOption> for PyClassImplCollector<FaEncoderOption>
fn new_text_signature(self) -> Option<&'static str>
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a FaEncoderOption
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a FaEncoderOption
Sourceimpl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut FaEncoderOption
impl<'a, 'py> PyFunctionArgument<'a, 'py> for &'a mut FaEncoderOption
Sourceimpl PyMethods<FaEncoderOption> for PyClassImplCollector<FaEncoderOption>
impl PyMethods<FaEncoderOption> for PyClassImplCollector<FaEncoderOption>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyStubType for FaEncoderOption
impl PyStubType for FaEncoderOption
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
Sourcefn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for FaEncoderOption
impl PyTypeInfo for FaEncoderOption
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourcefn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
fn type_object_bound(py: Python<'_>) -> Bound<'_, PyType>
👎Deprecated since 0.23.0: renamed to
PyTypeInfo::type_objectDeprecated name for
PyTypeInfo::type_object.Sourcefn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.Sourcefn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_type_of_bound(object: &Bound<'_, PyAny>) -> bool
👎Deprecated since 0.23.0: renamed to
PyTypeInfo::is_type_ofDeprecated name for
PyTypeInfo::is_type_of.Sourcefn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourcefn is_exact_type_of_bound(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of_bound(object: &Bound<'_, PyAny>) -> bool
👎Deprecated since 0.23.0: renamed to
PyTypeInfo::is_exact_type_ofDeprecated name for
PyTypeInfo::is_exact_type_of.Sourceimpl Serialize for FaEncoderOption
impl Serialize for FaEncoderOption
impl DerefToPyAny for FaEncoderOption